==> file_utility-8.x-1.0.tar.gz: file_utility/src/Form/FileUtilitySettingsForm.php <==
<?php

namespace Drupal\file_utility\Form;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ContentEntityExampleSettingsForm.
 *
 * @package Drupal\file_utility\Form
 * @ingroup content_entity_file_utility
 */
class FileUtilitySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'file_utility.fileutilityconfigurations',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'file_utility_configuration_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('file_utility.fileutilityconfigurations');

    $form['allowed_extensions'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Allowed Extensions'),
      '#description' => $this->t('Comma seprated file extension on which popup form works ex : pdf, txt, xls, xlsx, doc, docx, ppt, pptx, jpeg, png, gif'),
      '#size' => 64,
      '#default_value' => $config->get('allowed_extensions'),
    ];

    $form['open_model_file'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Open form on file click'),
      '#description' => $this->t('Check to open model form to save information about the user who download the file'),
      '#default_value' => $config->get('open_model_file'),
    ];

    $form['file_force_download'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('File Force Download'),
      '#description' => $this->t('Check to force download the file'),
      '#default_value' => $config->get('file_force_download'),
    ];

    $form['form_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Form Title'),
      '#description' => $this->t('Set form display name leave blank for none'),
      '#size' => 64,
      '#default_value' => $config->get('form_title'),
    ];

    $link = Link::fromTextAndUrl('Click Here', Url::fromUri("internal:/admin/people/permissions#module-file_utility", ['attributes' => ['target' => '_blank']]))->toString();

    $form['forgot_pass'] = [
      '#type' => 'markup',
      '#markup' => $this->t('Set access permission of file by role @link and Search File Utility', ['@link' => $link]),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $form_values = $form_state->getValues();
    if (empty($form_values['allowed_extensions'])) {
      $form_state->setErrorByName('allowed_extensions', $this->t('Fields cannot be empty.'));
    }
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('file_utility.fileutilityconfigurations')
      ->set('allowed_extensions', $form_state->getValue('allowed_extensions'))
      ->set('file_force_download', $form_state->getValue('file_force_download'))
      ->set('open_model_file', $form_state->getValue('open_model_file'))
      ->set('form_title', $form_state->getValue('form_title'))
      ->save();
  }

}

==> file_utility-8.x-1.1.tar.gz: file_utility/src/Form/FileUtilitySettingsForm.php <==
<?php

namespace Drupal\file_utility\Form;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ContentEntityExampleSettingsForm.
 *
 * @package Drupal\file_utility\Form
 * @ingroup content_entity_file_utility
 */
class FileUtilitySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'file_utility.fileutilityconfigurations',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'file_utility_configuration_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('file_utility.fileutilityconfigurations');

    $form['allowed_extensions'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Allowed Extensions'),
      '#description' => $this->t('Comma seprated file extension on which popup form works ex : pdf, txt, xls, xlsx, doc, docx, ppt, pptx, jpeg, png, gif'),
      '#size' => 64,
      '#required' => True,
      '#default_value' => $config->get('allowed_extensions'),
    ];

    $form['form_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Form Title'),
      '#description' => $this->t('Set form display name leave blank for none'),
      '#size' => 64,
      '#default_value' => $config->get('form_title'),
    ];

    $form['open_model_file'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Open form on file click'),
      '#description' => $this->t('Check to open model form to save information about the user who download the file'),
      '#default_value' => $config->get('open_model_file'),
    ];

    $form['file_force_download'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('File Force Download'),
      '#description' => $this->t('Check to force download the file'),
      '#default_value' => $config->get('file_force_download'),
    ];

    $form['subscription_checkbox'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Subscription Needed'),
      '#description' => $this->t('Check to show subscription checkbox on user pop up form'),
      '#size' => 64,
      '#default_value' => $config->get('subscription_checkbox'),
    ];

    $form['subscription_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subscription Checkbox Title'),
      '#description' => $this->t('Title to show next to subscription checkbox on user pop up form'),
      '#size' => 64,
      '#default_value' => $config->get('subscription_title'),
    ];

    $form['reply_email_checkbox'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Send Email'),
      '#description' => $this->t('Check if you want a Reply Email On Subscription or File Download'),
      '#size' => 64,
      '#default_value' => $config->get('reply_email_checkbox'),
    ];

    $form['admin_email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Reply Email Id'),
      '#description' => $this->t('The Reply Email in automated emails sent during Subscription and downloads of file, and other notifications. Set blank if you want to send reply email to default user'),
      '#size' => 64,
      '#default_value' => $config->get('admin_email'),
    ];

    $link = Link::fromTextAndUrl('Click Here', Url::fromUri("internal:/admin/people/permissions#module-file_utility", ['attributes' => ['target' => '_blank']]))->toString();

    $form['forgot_pass'] = [
      '#type' => 'markup',
      '#markup' => $this->t('Set access permission of file by role @link and Search File Utility', ['@link' => $link]),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $form_values = $form_state->getValues();//kint($form_values);die();
    if (!empty($form_values['subscription_checkbox']) && empty($form_values['subscription_title'])) {
      $form_state->setErrorByName('subscription_title', $this->t('Fields cannot be empty when subscription needed checked.'));
    }
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('file_utility.fileutilityconfigurations')
      ->set('allowed_extensions', $form_state->getValue('allowed_extensions'))
      ->set('file_force_download', $form_state->getValue('file_force_download'))
      ->set('open_model_file', $form_state->getValue('open_model_file'))
      ->set('form_title', $form_state->getValue('form_title'))
      ->set('subscription_checkbox', $form_state->getValue('subscription_checkbox'))
      ->set('subscription_title', $form_state->getValue('subscription_title'))
      ->set('reply_email_checkbox', $form_state->getValue('reply_email_checkbox'))
      ->set('admin_email', $form_state->getValue('admin_email'))
      ->save();
  }

}
